Crate serac

Crate serac 

A static, modular, and light-weight serialization framework.

Re-exports

pub use encoding::Encoding;
pub use medium::Medium;

Modules

encoding
error
medium

Macros

buf
Create an empty buffer for the provided type serialized with the provided encoding scheme. Optionally, a multiplier may be provided which is multiplied by the minimum buffer size.

Traits

SerializeBuf
This trait defines a more rigid/static serialization interface.
SerializeIter
This trait defines a highly adaptable interface for serializing and deserializing types to and from a serialization medium via iterators.
Size
This trait allows implementors to define the serialized size according to the encoding scheme.

Attribute Macros

serialize_buf
Generates the implementation block for conforming to SerializeBuf for a type alias. This is used for implementing SerializeBuf for concretely specified generic types.

Derive Macros

SerializeBuf
Generates the implementation block for conforming to SerializeBuf.