Module error
serac
0.2.1
Module error
Module Items
Structs
Enums
In crate serac
serac
Module
error
Structs

EndOf
Input
The encoder reached the end of the input before serialization/deserialization was complete.
Invalid
The contents of the serialization medium produced an invalid deserialized value.
Enums

Error
Deserialization failed.