Error

Enum Error 

#[repr(u8)]
pub enum Error { EndOfInput = 0, Invalid = 1, }
Deserialization failed.

Variants



EndOfInput = 0

The encoder reached the end of the input before deserialization was complete.



Invalid = 1

The contents of the serialization medium produced an invalid deserialized value.

Implementations

Source

impl Error

pub fn serialize_buf<'a>( &self, buf: &'a mut <Vanilla as Encoding>::Serialized<{ <Self as serac::SerializeBuf>::SIZE }>, ) -> usize
where &'a mut <Vanilla as Encoding>::Serialized<{ <Self as serac::SerializeBuf>::SIZE }>: IntoIterator<Item = &'a mut <Vanilla as Encoding>::Word> + 'a,

Serialize into the serialization medium.

pub fn deserialize_buf<'a>( src: &'a <Vanilla as Encoding>::Serialized<{ <Self as serac::SerializeBuf>::SIZE }>, ) -> Result<Self, Invalid>
where &'a <Vanilla as Encoding>::Serialized<{ <Self as serac::SerializeBuf>::SIZE }>: IntoIterator<Item = &'a <Vanilla as Encoding>::Word> + 'a,

Deserialize from the serialization medium.