buf

Macro buf 

macro_rules! buf {
    ($ty:ty: $enc:ty $(, $coef:expr)?) => { ... };
    ($ty:ty $(, $coef:expr)?) => { ... };
}
Create an empty buffer for the provided type serialized with the provided encoding scheme. Optionally, a multiplier may be provided which is multiplied by the minimum buffer size.