A static, modular, and light-weight serialization framework.
Re-exports
Modules
Macros
- buf
- Create an empty buffer for the provided type serialized with the provided encoding scheme. Optionally, a multiplier may be provided which is multiplied by the minimum buffer size.
Traits
- Serialize
Buf - This trait defines a more rigid/static serialization interface.
- Serialize
Iter - This trait defines a highly adaptable interface for serializing and deserializing types to and from a serialization medium via iterators.
- Size
- This trait allows implementors to define the serialized size according to the encoding scheme.
Attribute Macros
- serialize_
buf - Generates the implementation block for conforming to
SerializeBuffor a type alias. This is used for implementingSerializeBuffor concretely specified generic types.
Derive Macros
- Serialize
Buf - Generates the implementation block for conforming to
SerializeBuf.